import React, { Component, Fragment } from 'react';
import Debounce from 'lodash-decorators/debounce';
import Bind from 'lodash-decorators/bind';
import { connect } from 'dva';
import {
  Button,
  Menu,
  Dropdown,
  Icon,
  Row,
  Col,
  Steps,
  Card,
  Popover,
  Badge,
  Table,
  Tooltip,
  Divider,
} from 'antd';
import classNames from 'classnames';
import DescriptionList from 'components/DescriptionList';
import PageHeaderLayout from '../../layouts/PageHeaderLayout';
import styles from './AdvancedProfile.less';

const { Step } = Steps;
const { Description } = DescriptionList;
const ButtonGroup = Button.Group;

const getWindowWidth = () => window.innerWidth || document.documentElement.clientWidth;

const menu = (
  <Menu>
    <Menu.Item key="1">Options 1</Menu.Item>
    <Menu.Item key="2">Options 2</Menu.Item>
    <Menu.Item key="3">Options 3</Menu.Item>
  </Menu>
);

const action = (
  <Fragment>
    <ButtonGroup>
      <Button>Operating</Button>
      <Button>Operating</Button>
      <Dropdown overlay={menu} placement="bottomRight">
        <Button>
          <Icon type="ellipsis" />
        </Button>
      </Dropdown>
    </ButtonGroup>
    <Button type="primary">Main Operation</Button>
  </Fragment>
);

const extra = (
  <Row>
    <Col xs={24} sm={12}>
      <div className={styles.textSecondary}>Status</div>
      <div className={styles.heading}>Pending</div>
    </Col>
    <Col xs={24} sm={12}>
      <div className={styles.textSecondary}>Order Amount</div>
      <div className={styles.heading}>$ 568.08</div>
    </Col>
  </Row>
);

const description = (
  <DescriptionList className={styles.headerList} size="small" col="2">
    <Description term="Founder">John doe</Description>
    <Description term="Ordering Products">XX Service</Description>
    <Description term="Creation Time">2017-07-07</Description>
    <Description term="Associated Documents">
      <a href="">12421</a>
    </Description>
    <Description term="Effective Date">2017-07-07 ~ 2017-08-08</Description>
    <Description term="Note">Please confirm within two working days</Description>
  </DescriptionList>
);

const tabList = [
  {
    key: 'detail',
    tab: 'Details',
  },
  {
    key: 'rule',
    tab: 'Rule',
  },
];

const desc1 = (
  <div className={classNames(styles.textSecondary, styles.stepDescription)}>
    <Fragment>
      John Doe
      <Icon type="dingding-o" style={{ marginLeft: 8 }} />
    </Fragment>
    <div>2016-12-12 12:32</div>
  </div>
);

const desc2 = (
  <div className={styles.stepDescription}>
    <Fragment>
      Zhou Maomao
      <Icon type="dingding-o" style={{ color: '#00A0E9', marginLeft: 8 }} />
    </Fragment>
    <div>
      <a href="">Urgent</a>
    </div>
  </div>
);

const popoverContent = (
  <div style={{ width: 160 }}>
    Wu Jiahao
    <span className={styles.textSecondary} style={{ float: 'right' }}>
      <Badge status="default" text={<span style={{ color: 'rgba(0, 0, 0, 0.45)' }}>No Response</span>} />
    </span>
    <div className={styles.textSecondary} style={{ marginTop: 4 }}>
    Time-consuming: 2 hours and 25 minutes
    </div>
  </div>
);

const customDot = (dot, { status }) =>
  status === 'process' ? (
    <Popover placement="topLeft" arrowPointAtCenter content={popoverContent}>
      {dot}
    </Popover>
  ) : (
    dot
  );

const operationTabList = [
  {
    key: 'tab1',
    tab: 'Operation Log 1',
  },
  {
    key: 'tab2',
    tab: 'Operation Log 2',
  },
  {
    key: 'tab3',
    tab: 'Operation Log 3',
  },
];

const columns = [
  {
    title: 'Operation Type',
    dataIndex: 'type',
    key: 'type',
  },
  {
    title: 'Operator Name',
    dataIndex: 'name',
    key: 'name',
  },
  {
    title: 'Status',
    dataIndex: 'status',
    key: 'status',
    render: text =>
      text === 'agree' ? (
        <Badge status="success" text="Success" />
      ) : (
        <Badge status="error" text="Error" />
      ),
  },
  {
    title: 'Updated At',
    dataIndex: 'updatedAt',
    key: 'updatedAt',
  },
  {
    title: 'Note',
    dataIndex: 'memo',
    key: 'memo',
  },
];

@connect(({ profile, loading }) => ({
  profile,
  loading: loading.effects['profile/fetchAdvanced'],
}))
export default class AdvancedProfile extends Component {
  state = {
    operationkey: 'tab1',
    stepDirection: 'horizontal',
  };

  componentDidMount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'profile/fetchAdvanced',
    });

    this.setStepDirection();
    window.addEventListener('resize', this.setStepDirection);
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.setStepDirection);
    this.setStepDirection.cancel();
  }

  onOperationTabChange = key => {
    this.setState({ operationkey: key });
  };

  @Bind()
  @Debounce(200)
  setStepDirection() {
    const { stepDirection } = this.state;
    const w = getWindowWidth();
    if (stepDirection !== 'vertical' && w <= 576) {
      this.setState({
        stepDirection: 'vertical',
      });
    } else if (stepDirection !== 'horizontal' && w > 576) {
      this.setState({
        stepDirection: 'horizontal',
      });
    }
  }

  render() {
    const { stepDirection } = this.state;
    const { profile, loading } = this.props;
    const { advancedOperation1, advancedOperation2, advancedOperation3 } = profile;
    const contentList = {
      tab1: (
        <Table
          pagination={false}
          loading={loading}
          dataSource={advancedOperation1}
          columns={columns}
        />
      ),
      tab2: (
        <Table
          pagination={false}
          loading={loading}
          dataSource={advancedOperation2}
          columns={columns}
        />
      ),
      tab3: (
        <Table
          pagination={false}
          loading={loading}
          dataSource={advancedOperation3}
          columns={columns}
        />
      ),
    };

    return (
      <PageHeaderLayout
        title="Unique Number：234231029431"
        logo={
          <img alt="" src="https://gw.alipayobjects.com/zos/rmsportal/nxkuOJlFJuAUhzlMTCEe.png" />
        }
        action={action}
        content={description}
        extraContent={extra}
        tabList={tabList}
      >
        <Card title="Process Progress" style={{ marginBottom: 24 }} bordered={false}>
          <Steps direction={stepDirection} progressDot={customDot} current={1}>
            <Step title="Create a Project" description={desc1} />
            <Step title="Department First Review" description={desc2} />
            <Step title="Financial Review" />
            <Step title="Carry Out" />
          </Steps>
        </Card>
        <Card title="User Info" style={{ marginBottom: 24 }} bordered={false}>
          <DescriptionList style={{ marginBottom: 24 }}>
            <Description term="Username">Fu Xiaoxiao</Description>
            <Description term="Member Card Number">32943898021309809423</Description>
            <Description term="ID Card">3321944288191034921</Description>
            <Description term="Contact Information">18112345678</Description>
            <Description term="Contact Address">
              John Doe 18100000000 Intersection of Gonggu Road, Huanggushan Road, Xihu District, Hangzhou City, Zhejiang Province, China
            </Description>
          </DescriptionList>
          <DescriptionList style={{ marginBottom: 24 }} title="Information Group">
            <Description term="Certain Data">725</Description>
            <Description term="Update Date">2017-08-08</Description>
            <Description>&nbsp;</Description>
            <Description
              term={
                <span>
                  Centain Data
                  <Tooltip title="Data Shows">
                    <Icon
                      style={{ color: 'rgba(0, 0, 0, 0.43)', marginLeft: 4 }}
                      type="info-circle-o"
                    />
                  </Tooltip>
                </span>
              }
            >
              725
            </Description>
            <Description term="Update Date">2017-08-08</Description>
          </DescriptionList>
          <h4 style={{ marginBottom: 16 }}>Information Group</h4>
          <Card type="inner" title="Multilevel Information Group">
            <DescriptionList size="small" style={{ marginBottom: 16 }} title="Group Name">
              <Description term="Principal">Lin Dongdong</Description>
              <Description term="Role Code">1234567</Description>
              <Description term="Department">XX Company - YY Unit</Description>
              <Description term="Expiration">2017-08-08</Description>
              <Description term="Description">
              This description is very long, long, long, long, long, long, long, long, long, long, long, long, long,...
              </Description>
            </DescriptionList>
            <Divider style={{ margin: '16px 0' }} />
            <DescriptionList size="small" style={{ marginBottom: 16 }} title="Group Name" col="1">
              <Description term="Scientific Name">
                Citrullus lanatus (Thunb.) Matsum. et
                Nakai一年生蔓生藤本；茎、枝粗壮，具明显的棱。卷须较粗.. 
              </Description>
            </DescriptionList>
            <Divider style={{ margin: '16px 0' }} />
            <DescriptionList size="small" title="Group Name">
              <Description term="Principal">Fu Xiaoxiao</Description>
              <Description term="Role Code">1234568</Description>
            </DescriptionList>
          </Card>
        </Card>
        <Card title="User's call record in the past six months" style={{ marginBottom: 24 }} bordered={false}>
          <div className={styles.noData}>
            <Icon type="frown-o" />No Data
          </div>
        </Card>
        <Card
          className={styles.tabsCard}
          bordered={false}
          tabList={operationTabList}
          onTabChange={this.onOperationTabChange}
        >
          {contentList[this.state.operationkey]}
        </Card>
      </PageHeaderLayout>
    );
  }
}
